@@ -2,7 +2,7 @@
 #'
 #' @description
 #'
-#' Create a \pkg{sf} polygon object from the coordinates of a bounding box
+#' Create a \CRANpkg{sf} polygon object from the coordinates of a bounding box
 #'
 #' @param bbox numeric vector of 4 elements representing the coordinates of the
 #'   bounding box. Values should be `c(xmin, ymin, xmax, ymax)`
@@ -41,24 +41,21 @@
 #'
 #' sfobj
 #'
-#' bbox <- sf::st_bbox(sfobj)
+#' # Need at least one non-empty object
+#' if (any(!sf::st_is_empty(sfobj))) {
+#'   bbox <- sf::st_bbox(sfobj)
 #'
-#' bbox
+#'   bbox
 #'
-#' bbox_sfobj <- bbox_to_poly(bbox)
+#'   bbox_sfobj <- bbox_to_poly(bbox)
 #'
-#' ggplot(bbox_sfobj) +
-#'   geom_sf(fill = "lightblue", alpha = 0.5) +
-#'   geom_sf(data = sfobj, fill = "wheat")
+#'   ggplot(bbox_sfobj) +
+#'     geom_sf(fill = "lightblue", alpha = 0.5) +
+#'     geom_sf(data = sfobj, fill = "wheat")
+#' }
 #' }
 #' @export
-
-
-bbox_to_poly <- function(bbox = NA,
-                         xmin = NA,
-                         ymin = NA,
-                         xmax = NA,
-                         ymax = NA,
+bbox_to_poly <- function(bbox = NA, xmin = NA, ymin = NA, xmax = NA, ymax = NA,
                          crs = 4326) {
   if (!anyNA(bbox) && length(bbox) != 4) {
     stop(
@@ -68,7 +65,6 @@ bbox_to_poly <- function(bbox = NA,
   }
 
   # If no bbox check x and y values
-
   if (anyNA(bbox)) {
     bbox <- as.double(c(xmin, ymin, xmax, ymax))
 
@@ -77,8 +73,6 @@ bbox_to_poly <- function(bbox = NA,
     }
   }
 
-
-
   bbox_double <- as.double(bbox)
   names(bbox_double) <- c("xmin", "ymin", "xmax", "ymax")
   class(bbox_double) <- "bbox"
